# ROADMAP

* [1. Introduction](#1-Introduction)
* [2. Achieved ](#2-Achieved)
* [3. Future](#3-Future)

## 1. Introduction

This document will serve as a ROADMAP for the project. 

## 2. Achieved

Here are listed the milestone achieved by the project team

1. Literature Review

2. Environment
    > [Implement Any 2D Environment](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/arena_examples/2d_arenas_examples.ipynb)
    
    > [Merging room](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/arena_examples/2d_merging_rooms_examples.ipynb) 
    
3. Agent
      > [" Learning place cells, grid cells and invariances with excitatory and inhibitory", Weber et al, 2018](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/agent_examples/weber_2018_example.ipynb)

     > [" A general model of hippocampal and dorsal striatal learning and decision making", Stachenfeld et al, 2018](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/agent_examples/stachenfeld_2018_examples.ipynb)
     
     > [" The Tolman-Eichenbaum Machine: Unifying Space and Relational Memory through Generalization in the Hippocampal Formation", Whittington et al, 2020](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/agent_examples/whittington_2020_examples.ipynb)
 
   
4. Experiments 
    > [" Conjunctive Representation of Position, Direction, and Velocity in Entorhinal Cortex", Sargolini et al, 2006](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/experimental_examples/Sargolini_2006_examples.ipynb)
 
    > [" Hippocampus-independent phase precession in entorhinal grid cells", Hafting et al, 2008](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/experimental_examples/Hafting_2008_examples.ipynb)


    > [" Integration of grid maps in merged environments", Wernle et al, 2018](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/experimental_examples/Wernle_2018_examples.ipynb)
  
   
Congratulation Team!


## 3. Future

1. Environment
   > *Insert suggestion here*
    
2. Agent
   > *Insert suggestion here*
    
3. Experiments 
    > *Insert suggestion here*
      
4. Comparison Board  
    > *Insert suggestion here*

5. Public Access
    > *Insert suggestion here*
  

Let's go Team! 
